from setuptools import setup

setup(name='general_gaussian_and_binomial_distributions',
      version='0.1',
      description='Different distributions',
      packages=['general_gaussian_and_binomial_distributions'],
      author='Ashish Karn',
      author_email='er.ashishkarn@gmail.com',
      zip_safe=False)
